@@ -7,7 +7,7 @@ __END__
 
 =head1 \tgEFA
 
-Sjis-JA - "Yet Another JPerl" Source code filter to escape ShiftJIS (Japanese document)
+Sjis-JA - Source code filter to escape ShiftJIS (Japanese document)
 
 =head1 Tv
 
@@ -181,8 +181,7 @@ GXP[v_قȂ܂B
 
 ̃\tgEFA͉ߋ̂̂󂵂͂AɁuGXP[vvɂċ@\ǉ
 Ă܂B獡܂ŉ\łƂs\ɂȂ邱Ƃ͂܂B
-̃Av[`́AނċȂɗLłB_Perlɖ
-łƂ͌Ȃ̂łB
+̃Av[`́AނċȂɗLłB
 
 =head1 XNvg̃GXP[v
 
@@ -191,7 +190,7 @@ GXP[v_قȂ܂B
   ---------------------------------
   ȑO        Ȍ
   ---------------------------------
-  use utf8;   use Sjis;
+  (Ȃ)      use Sjis;
   ---------------------------------
 
 =head1 }`oCg̃GXP[v
@@ -291,7 +290,9 @@ Esjis::* ֐ Esjis.pm 񋟂܂B
   index       Esjis::index
   rindex      Esjis::rindex
   lc          Esjis::lc
+  lcfirst     Esjis::lcfirst
   uc          Esjis::uc
+  ucfirst     Esjis::ucfirst
   chr         Esjis::chr
   glob        Esjis::glob
   lstat       Esjis::lstat
@@ -316,7 +317,7 @@ Esjis::* ֐ Esjis.pm 񋟂܂B
 
 =head1 t@CeXgZq̃GXP[v
 
-̃\tgEFAɂĊ֐̉Zq '-'  'Esjis::' ɏ܂B
+̃\tgEFAɂĉZq '-'  'Esjis::' ɏ܂B
 
   ---------------------------------
   O      
@@ -382,7 +383,7 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
 
 =over 2
 
-=item * ord  Sjis::ord ܂ Sjis::ord_ ɏ܂
+=item * Sjis::ord
 
     "use Sjis qw(ord);" ɂ ord  Sjis::ord ɏ悤ɂȂ܂B
 
@@ -395,7 +396,7 @@ WW[̃t@C /Perl/site/lib/Sjis ɃRs[ 'use utf8;'
     ̓ JPerl Ɣ݊Ȃ̂ŖIɃC|[gꍇ̂݋@\悤
     ȂĂ܂B
 
-=item * reverse  Sjis::reverse ɏ܂
+=item * Sjis::reverse
 
     "use Sjis qw(reverse);" ɂ reverse  Sjis::reverse ɏ悤
     ɂȂ܂B
@@ -1363,7 +1364,7 @@ vO~O񋟂܂B
 
  K\NbNubN
  Jan Goyvaerts, Steven Levithan ,  O 
- 2010N0414 \
+ 2010N04 s
  552y[W
  ISBN978-4-87311-450-7
  http://www.oreilly.co.jp/books/9784873114507/
@@ -1386,16 +1387,22 @@ vO~O񋟂܂B
  T1008901080816 G08901-8
  http://ascii.asciimw.jp/books/magazines/unix.shtml
 
- ֘A\tgEFA
+ Sjis \tgEFAt@~[
+ http://search.cpan.org/dist/Big5HKSCS/
  http://search.cpan.org/dist/Big5Plus/
  http://search.cpan.org/dist/EUCJP/
  http://search.cpan.org/dist/GB18030/
  http://search.cpan.org/dist/HP15/
  http://search.cpan.org/dist/INFORMIXV6ALS/
+ http://search.cpan.org/dist/Latin1/
+ http://search.cpan.org/dist/OldUTF8/
  http://search.cpan.org/dist/Sjis/
  http://search.cpan.org/dist/UHC/
  http://search.cpan.org/dist/UTF2/
+
+ ֘A\tgEFA
  http://search.cpan.org/dist/jacode/
+ http://search.cpan.org/dist/Char/
 
 =head1 ӎ
 
@@ -1425,8 +1432,11 @@ vO~O񋟂܂B
   av, jperl[U[̂߂
  http://homepage1.nifty.com/kazuf/jperl.html
 
+ Bruce., Unicode in Perl
+ http://www.rakunet.org/TSNET/TSabc/18/546.html
+
  a G, WindowsPerl 5.8/5.10gȂ
- http://www.aritia.org/hizumi/perl/perlwin.html
+ http://www.aritia.jp/hizumi/oldtext/perlwin.html
 
  ˖{ q, Perl/Windowsł̃t@CpX
  http://digit.que.ne.jp/work/wiki.cgi?Perl%E3%83%A1%E3%83%A2%2FWindows%E3%81%A7%E3%81%AE%E3%83%95%E3%82%A1%E3%82%A4%E3%83%AB%E3%83%91%E3%82%B9
@@ -1456,6 +1466,9 @@ vO~O񋟂܂B
  daily dayflower, 2008-06-25 perluniadvice
  http://d.hatena.ne.jp/dayflower/20080625/1214374293
 
+ Jesse Vincent, Compatibility is a virtue
+ http://www.nntp.perl.org/group/perl.perl5.porters/2010/05/msg159825.html
+
  Tokyo-pm ۑ
  http://mail.pm.org/pipermail/tokyo-pm/
  http://mail.pm.org/pipermail/tokyo-pm/1999-September/001844.html
